@@ -631,12 +631,15 @@ set_auto_command(			int j,
 
 	      if (queued && *queued && output_arg) command=g_strdup(app);
 	      else {
+#ifdef USE_SMB_BRANCH
 		  if (strncmp(path,"//",strlen("//"))==0){
 		      gchar *netpath=g_build_filename(XF_SMBget_netfile_cache_dir(),strrchr(path,'/')+1,NULL);
 		      command=g_strdup(MIME_mk_command_line(app,netpath,FALSE,FALSE));
 		      g_free(netpath);
 		  }
-		  else command=g_strdup(MIME_mk_command_line(app,path,FALSE,FALSE));
+		  else 
+#endif
+		      command=g_strdup(MIME_mk_command_line(app,path,FALSE,FALSE));
 	      }
 	      
 	      /* check for duplicates */
