@@ -1,3 +1,4 @@
+#ifdef USE_SMB_BRANCH
 #define UNDEFINED		0x01
 #define CHALLENGED		0x02
 #define FAILED			0x04
@@ -9,3 +10,5 @@ int
 SMBLookup (GtkTreeView *treeview,unsigned char *servidor,
 		GtkTreeIter *iter,int caso,
 		char *pass);
+#endif
+
