@@ -37,6 +37,7 @@
 
 #include "xmcs-manager.h"
 
+#include "easy.h"
 #include "dnd.h"
 #include "callbacks.h"
 #include "goto.h"
@@ -295,7 +296,7 @@ static gboolean escape2xfrun(int argc, char *argv[]){
 	g_free(arguments);
 	arguments = g;
     }
-    g_message("%s\n",arguments);
+    DBG("%s\n",arguments);
     
     if (g_shell_parse_argv(arguments,&argcp,&argvp,&error)){
 	execvp(argvp[0],argvp);
@@ -375,7 +376,7 @@ int main(int argc, char *argv[])
     session_client = client_session_new (argc,argv, NULL,SESSION_RESTART_IF_RUNNING,1);
     if(!session_init(session_client))
     {
-	g_message("Cannot connect to session manager");
+	g_warning("Cannot connect to session manager");
     }
 
     init_xffm_env(); /* allocate memory for dynamic environment variables */
