@@ -228,7 +228,7 @@ static void notify_cb(const char *name, const char *channel_name, McsAction acti
 	return;
     if(g_ascii_strcasecmp(CHANNEL, channel_name))
     {
-	g_message("This should not happen");
+	g_warning("This should not happen");
 	return;
     }
 
